@@ -3,7 +3,7 @@ import pytest
 from plotly import optional_imports
 from ...utils import compare_dict, strip_dict_params
 from ...test_optional.optional_utils import run_fig
-from ...test_optional.test_matplotlylib.data.subplots import *
+from ...test_optional.test_matplotlylib.data.subplots import D, BLANK_SUBPLOTS
 
 matplotlylib = optional_imports.get_module("plotly.matplotlylib")
 
